#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "importevents.h"
#include "spinboxdelegate.h"
#include <QSqlQuery>
#include <QSqlDatabase>
#include <QSqlError>
#include <QSqlRecord>
#include <QFile>
#include <QDir>
#include <QDebug>
#include <QSqlQueryModel>
#include <QMenuBar>
#include <QMessageBox>
#include <QUrl>
#include <QWebFrame>
#include <QTreeWidgetItem>
#include <QPlastiqueStyle>

QSqlDatabase db;
QString sSelectedGroup = "";
QString sSelectedRound = "All";
QString sSelectedSport  = "";
QString sSelectedRegion = "";
QString sSelectedEvent = "";
QString sSelectedSeason = "";
int iSelectedSoccerDBID;
importevents *dlgImportEvents;
QHash<QString, int> hGroups;
QHash<QString, int> hTeams;
//int iEventID;

struct Standing {
    int iTeamRowID;
    QString sTeamName;
    int iPoints;
    int iWins;
    int iDraws;
    int iLosses;
    int iScored;
    int iConceeded;
} stStanding;

//QList<Standing> listStanding;
QHash<int, Standing> hStanding;

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    dlgImportEvents = new importevents;
    loadMenu();
    QFile file("");
    if (existDatabase())
    {
        ui->tab->setVisible(false);
        ui->tab->setEnabled(false);
        ui->tab_2->setVisible(false);
        ui->tab_2->setEnabled(false);

        if (populateFavourites() == 0)
        {
            ui->tabWidget->setCurrentWidget(ui->tab_5);
        }
        else
        {
            ui->tabWidget->setCurrentWidget(ui->tab_Favourites);
        };
        populateSportCombo();
//        populateEventCombo();
//        populateGroupCombo();
//        populateRoundCombo();
//        populateTeamCombo();
//        sSelectedRound = "All";
//        sSelectedGroup = "All";
//        displayGames();
//        showStandings();

        ui->webView_2->settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
        ui->webView->settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
        ui->webView->setStyle(new QPlastiqueStyle);
        ui->webView_2->setStyle(new QPlastiqueStyle);
        ui->webView->setProperty("FingerScrollable", true);
        ui->webView_2->setProperty("FingerScrollable", true);
        ui->twSelect->setProperty("FingerScrollable", true);
        ui->twSelect->setStyle(new QPlastiqueStyle);
        showOnlineLeague(714); //Italy - Serie A - 2009-10
    }

    ui->twFavourites->horizontalHeader()->setResizeMode(0,QHeaderView::ResizeToContents);
    ui->twFavourites->horizontalHeader()->setResizeMode(1,QHeaderView::ResizeToContents);
    ui->twFavourites->horizontalHeader()->setResizeMode(2,QHeaderView::ResizeToContents);
    ui->twFavourites->horizontalHeader()->setResizeMode(3,QHeaderView::ResizeToContents);
    ui->twFavourites->horizontalHeader()->setResizeMode(4,QHeaderView::ResizeToContents);

    connect(ui->twSelect,SIGNAL(itemClicked(QTreeWidgetItem*,int)),this,SLOT(showSelectedEvent(QTreeWidgetItem*)));

}

void MainWindow::showSelectedEvent(QTreeWidgetItem *qtwiSelected)
{
    if (qtwiSelected->type() == typeSeason)
    {
        sSelectedSeason = qtwiSelected->text(0);
        sSelectedEvent = qtwiSelected->parent()->text(0);
        sSelectedRegion = qtwiSelected->parent()->parent()->text(0);
        sSelectedSport = qtwiSelected->parent()->parent()->parent()->text(0);
        qDebug() << sSelectedSeason << sSelectedEvent << sSelectedRegion << sSelectedSport;
        on_cbSeason_activated(sSelectedSeason);
        ui->tabWidget->setCurrentWidget(ui->tab_3);
    }
}

void MainWindow::showOnlineLeague(int iSelectedSoccerDBID)
{
    QString sHTML;
    QString sSelectedSoccerDBID;
    QString sStyle;
    QPalette palette;
    sSelectedSoccerDBID.setNum(iSelectedSoccerDBID);

    sStyle = "<style type='text/css'>"
    ".Date "
    "{"
    "        font-family: verdana, geneva, arial, helvetica, sans-serif; "
    "        background-color: #4F81BD;"
    "        padding: 2px;"
    "        margin: 5px;"
    "        border-style: solid; "
    "        border-color: #8EB4E3;"
    "        border-width: 2px; "
    "        -moz-border-radius: 5px;"
    "}"
    ".Match "
    "{"
    "        font-family: verdana, geneva, arial, helvetica, sans-serif; "
    "        color: black; "
    "        background-color: #8EB4E3;"
    "        padding: 2px 1px;    }"
    ".header {"
    "        font-family: verdana, geneva, arial, helvetica, sans-serif; "
    "        font-weight: bold;"
    "        padding: 2px;    }"
    ".odd {"
    "        background-color: #ebebeb;"
    "        font-family: verdana, geneva, arial, helvetica, sans-serif; "
    "        padding: 2px;    }"
    ".even {"
    "        background-color: #fff;"
    "        font-family: verdana, geneva, arial, helvetica, sans-serif; "
    "        padding: 2px;    }"
    ".lines {background-color: #000;}"
    ".highlight {font-weight: bold;}"
    "</style>";


    //background='qsportsevent1.jpg'
    sHTML = "<HTML>" + sStyle + "<body><script type='text/javascript' src='http://www.aragon.ws/soccerdb/getmatches.php?id=" + sSelectedSoccerDBID + "&date=latest&css=Match&cssDate=Date'></script></body></HTML>";
    qDebug() << "sHTML :" << sHTML ;

    palette = ui->webView->palette();
    palette.setBrush(QPalette::Base, Qt::transparent);
    ui->webView->page()->setPalette(palette);
    ui->webView->setAttribute(Qt::WA_OpaquePaintEvent, false);
    ui->webView->setAttribute(Qt::WA_TranslucentBackground, true);
    ui->webView->setHtml(sHTML, QUrl::fromLocalFile(QDir::currentPath()));

    ui->webView->show();
    qDebug() << "webView:" << ui->webView->page()->mainFrame()->toHtml();

    ui->webView_2->settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
    sHTML = "<HTML>" + sStyle + "<body><script type='text/javascript' src='http://www.aragon.ws/soccerdb/gettable.php?id=" + sSelectedSoccerDBID + "&&showHeader=true&cssHeader=header&cssLines=lines&css1=odd&css2=even'></script></body></HTML>";
    palette = ui->webView_2->palette();
    palette.setBrush(QPalette::Base, Qt::transparent);
    ui->webView_2->page()->setPalette(palette);
    ui->webView_2->setAttribute(Qt::WA_OpaquePaintEvent, false);
    ui->webView_2->setAttribute(Qt::WA_TranslucentBackground, true);
    ui->webView_2->setHtml(sHTML, QUrl::fromLocalFile(QDir::currentPath()));
    ui->webView_2->show();
    qDebug() << "webView_2:" << ui->webView_2->page()->mainFrame()->toHtml();

// Display generated HTML in temp edit control //
//    ui->txtHTML->setText(ui->webView->);
}

bool MainWindow::existDatabase()
{

    QFile fDbFile;
    QString path;
    bool existDb;

#ifdef Q_OS_LINUX
        // NOTE: We have to store database file into user home folder in Linux
//            QString path(QDir::home().path());
        path = QDir::home().path();
        path.append(QDir::separator()).append("qsportsevent.db");
        path = QDir::toNativeSeparators(path);
#else
        path = "./qsportsevent.db" ;
        // NOTE: File exists in the application private folder, in Symbian Qt implementation
#endif
        fDbFile.setFileName(path);
        qDebug() << "Db path:" << path;
        qDebug() << "fDbFile.exists():" << fDbFile.exists();
        existDb = fDbFile.exists();

        if (existDb)
        {
            QSqlDatabase db;
            db = QSqlDatabase::addDatabase("QSQLITE");
            db.setDatabaseName(path);
            if (!db.open())
            {
                qDebug() << "Failed to connect";
                qDebug() << db.lastError();
            }
        }

        return existDb ;
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void MainWindow::loadMenu()
{
    QMenuBar *menuBar=new QMenuBar();
    QAction *showImportEvents=new QAction("Import Event",this);
    menuBar->addAction(showImportEvents);
    connect(showImportEvents,SIGNAL(triggered()),this,SLOT(showImportEvents()));
    QAction *showAbout=new QAction("About",this);
    menuBar->addAction(showAbout);
    connect(showAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
    setMenuBar(menuBar);
}

void MainWindow::showImportEvents()
{

    dlgImportEvents->show();
    if (dlgImportEvents->exec() == QDialog::Accepted)
    {
    }
//    populateEventCombo();
    populateSportCombo();
//    populateGroupCombo();
//    populateRoundCombo();
//    populateTeamCombo();
//    displayGames();
//    showStandings();
}


void MainWindow::displayGames()
{
    QSqlQuery qry;
    QString sql;
    QString sqlAppend1;
    QString sqlAppend2;
//    QSqlQueryModel *model = new QSqlQueryModel;
    QString str;
 //   QString sql ="SELECT * FROM Games ORDER BY gametime ASC";
/*
    QString sql ="SELECT games.gametime, games.venue, hometeam.name, awayteam.name, games.homegoals, games.awaygoals "
                 "FROM Games, teamgroups, teams as hometeam, teams as awayteam "
                 "WHERE games.awayteamrowid = awayteam.rowid "
                 "AND  games.hometeamrowid = hometeam.rowid "
                 "AND games.grouprowid = teamgroups.rowid "
                 "ORDER BY teamgroups.name, games.gametime ASC";
*/
//                 "WHERE games.awayteamrowid = awayteam.rowid ";
//                 "AND  games.hometeamrowid = hometeam.rowid "
//                 "AND games.grouprowid = teamgroups.rowid "
//                "ORDER BY teamgroups.name, games.gametime ASC";
//    QTableView *view;
//    tbwGames
/*
    sql ="SELECT * "
                 "FROM Games ";
    model->setQuery(sql,db); // DB is a QSqlDatabase object
    qDebug() << "lastError" << model->lastError();
    ui->tbwGames->setModel(model);

    QSqlQueryModel *model2 = new QSqlQueryModel;
    sql ="SELECT rowid, * from Games";
    model2->setQuery(sql,db); // DB is a QSqlDatabase object
    qDebug() << "lastError" << model2->lastError();
    ui->tbvGames->setModel(model2);

    QSqlQueryModel *model3 = new QSqlQueryModel;
    sql ="SELECT rowid, * from Teams";
    model3->setQuery(sql,db); // DB is a QSqlDatabase object
    qDebug() << "lastError" << model3->lastError();
    ui->tbvTeams->setModel(model3);

    QSqlQueryModel *model4 = new QSqlQueryModel;
    sql ="SELECT rowid, * from teamgroups";
    model4->setQuery(sql,db); // DB is a QSqlDatabase object
    qDebug() << "lastError" << model4->lastError();
    ui->tbvGroups->setModel(model4);
*/



    sql = "SELECT rowid, name from teamgroups "
          "WHERE eventrowid=:eventrowid";

    qry.prepare(sql);
    qry.bindValue("eventrowid:", iEventID);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    while (qry.next()) {
        //Default group is the first one.
        if (sSelectedGroup == "")
        {
            sSelectedGroup = qry.value(1).toString();
        }
        hGroups[qry.value(1).toString()] = qry.value(0).toInt();
        qDebug() << qry.value(0).toString();
        qDebug() << qry.value(1).toString();
    }

    qDebug() << sSelectedGroup;

    sql = "SELECT rowid, name from teams ";
    if (sSelectedGroup != "All")
    {
        sqlAppend1 = " WHERE grouprowid=" + QString::number(hGroups.value(sSelectedGroup),10);
        qDebug() << sqlAppend1;
        qDebug() << hGroups.value(sSelectedGroup);
    }

    qry.prepare(sql + sqlAppend1);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    hTeams.clear();
    hStanding.clear();
    qDebug() << hTeams.keys();
    qDebug() << hTeams.values();

    while (qry.next()) {
        Standing stTeam;
        hTeams[qry.value(1).toString()] = qry.value(0).toInt();
        stTeam.sTeamName = qry.value(1).toString();
        stTeam.iPoints = 0;
        stTeam.iWins = 0;
        stTeam.iDraws = 0;
        stTeam.iLosses = 0;
        stTeam.iScored = 0;
        stTeam.iConceeded = 0;
        stTeam.iTeamRowID = qry.value(0).toInt();
        hStanding[qry.value(0).toInt()] = stTeam;
        qDebug() << qry.value(1).toString() << qry.value(0).toString();
        qDebug() << hTeams.keys();
        qDebug() << hTeams.values();
    }

    sqlAppend1="";
    sqlAppend2="";
    sql ="SELECT grouprowid, gametime, hometeamrowid, awayteamrowid, homegoals, awaygoals, round from games ";
    if (sSelectedGroup != "All")
    {
        sqlAppend1 = " grouprowid=" + QString::number(hGroups.value(sSelectedGroup),10);
        qDebug() << sqlAppend1;
        qDebug() << hGroups.value(sSelectedGroup);
    }

    if (sSelectedRound != "All")
    {
        sqlAppend2 = " round='" + sSelectedRound + "'";
    }

    if (sqlAppend1 != "" && sqlAppend2 != "")
    {
        sql = sql + " WHERE " + sqlAppend1 + " AND " + sqlAppend2;
    }
    else if (sqlAppend1 != "")
    {
        sql = sql + " WHERE " + sqlAppend1 ;
    }
    else if (sqlAppend2 != "")
    {
        sql = sql + " WHERE " + sqlAppend2;
    }

    qry.prepare(sql);

    qDebug() << sql;

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    qDebug() << "qry.size()" << qry.size();
    ui->twGames->clear();
//    ui->twGames->setAlternatingRowColors(true);

    ui->twGames->setRowCount(48);//qry.size());
    ui->twGames->setColumnCount(6);

    qDebug() << hTeams.keys();
    qDebug() << hTeams.values();
    qDebug() << hGroups.keys();
    qDebug() << hGroups.values();
    int row=0;
    while (qry.next()) {
        for (int column = 0; column < 6; column++)
        {
            switch (column)
            {
            case 0:
                qDebug() << "Group:" << qry.value(column).toString();
                str = hGroups.key(qry.value(column).toInt());
                qDebug() << "str" << str;
                break;
            case 2:
            case 3:
                qDebug() << "Team:" << qry.value(column).toString();
                str = hTeams.key(qry.value(column).toInt());
                qDebug() << "str" << str;
                break;
            case 1:
            case 4:
            case 5:
                qDebug() << "item" << qry.value(column).toString();
                str = qry.value(column).toString();
                break;
            }
            QTableWidgetItem *newItem = new QTableWidgetItem(str);
            ui->twGames->setItem(row, column, newItem);
        }
        row++;
     }
    ui->twGames->resizeColumnsToContents();
    ui->twGames->setItemDelegateForColumn(4, new SpinBoxDelegate(ui->twGames));
    ui->twGames->setItemDelegateForColumn(5, new SpinBoxDelegate(ui->twGames));
    ui->twGames->setColumnWidth(4,40);
    ui->twGames->setColumnWidth(5,40);
}

void MainWindow::populateGroupCombo()
{
    QSqlQuery qry;

    qry.prepare("SELECT rowid, name "
                 "FROM teamgroups "
                 "WHERE eventrowid=:eventrowid");

    qry.bindValue(":eventrowid", iEventID);
    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    ui->cbGroups->clear();
    ui->cbGroups->addItem("All");
    while (qry.isValid())
    {
        ui->cbGroups->addItem(qry.value(1).toString());
        qry.next();
    }
}

void MainWindow::populateSportCombo()
{
    QSqlQuery qry;

    qry.prepare("SELECT DISTINCT sport "
                "FROM events "
                "ORDER BY sport ASC");

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    ui->twSelect->setColumnCount(1);
    QList<QTreeWidgetItem *> lSports;
//    QTreeWidgetItem qtwiSports;

//    ui->cbSport->clear();
    while (qry.isValid())
    {
//        ui->cbSport->addItem(qry.value(0).toString());
        QTreeWidgetItem *qtwiSports = new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString()),typeSport);
        qtwiSports->addChildren(getRegions(qry.value(0).toString()));
        lSports.append(qtwiSports);
//        lSports.append(new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString())));
        qry.next();
    }
    ui->twSelect->insertTopLevelItems(0, lSports);
}

QList<QTreeWidgetItem *> MainWindow::getRegions(QString sSport)
{
    QList<QTreeWidgetItem *> lRegions;
    QSqlQuery qry;

    qry.prepare("SELECT DISTINCT region "
                 "FROM events "
                 "WHERE sport=:sport "
                 "ORDER BY region ASC");
    qry.bindValue(":sport", sSport);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    while (qry.isValid())
    {

        QTreeWidgetItem *qtwiRegions = new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString()),typeRegion);
        qtwiRegions->addChildren(getEvents(sSport, qry.value(0).toString()));
        lRegions.append(qtwiRegions);

        qry.next();
    }
    return lRegions;
}

QList<QTreeWidgetItem *> MainWindow::getEvents(QString sSport, QString sRegion)
{
    QList<QTreeWidgetItem *> lEvents;
    QSqlQuery qry;

//    bool bFirst = true;
    qry.prepare("SELECT DISTINCT name "
                 "FROM events "
                 "WHERE sport=:sport and region=:region "
                 "ORDER BY name ASC");
    qry.bindValue(":sport", sSport);
    qry.bindValue(":region", sRegion);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    while (qry.isValid())
    {

        QTreeWidgetItem *qtwiEvents = new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString()),typeEvent);
        qtwiEvents->addChildren(getSeasons(sSport, sRegion, qry.value(0).toString()));
        lEvents.append(qtwiEvents);

        qry.next();
    }
    return lEvents;
}

QList<QTreeWidgetItem *> MainWindow::getSeasons(QString sSport, QString sRegion, QString sEventName)
{
    QList<QTreeWidgetItem *> lSeasons;
    QSqlQuery qry;

    qry.prepare("SELECT DISTINCT season "
                 "FROM events "
                 "WHERE sport=:sport and region=:region and name=:name "
                 "ORDER BY season DESC");
    qry.bindValue(":sport", sSport);
    qry.bindValue(":region", sRegion);
    qry.bindValue(":name", sEventName);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    while (qry.isValid())
    {
        lSeasons.append(new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString()),typeSeason));
//        QTreeWidgetItem *qtwiEvents = new QTreeWidgetItem((QTreeWidget*)0, QStringList(qry.value(0).toString()),typeEvent);
        qry.next();
    }
    return lSeasons;
}
void MainWindow::populateRegionCombo(QString sSport)
{
    QSqlQuery qry;

    qry.prepare("SELECT DISTINCT region "
                 "FROM events "
                 "WHERE sport=:sport");
    qry.bindValue(":sport", sSport);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

//    ui->cbRegion->clear();
    while (qry.isValid())
    {
//        ui->cbRegion->addItem(qry.value(0).toString());
        qry.next();
    }
}

void MainWindow::populateTeamCombo()
{
    QSqlQuery qry;
    QString sql;
    QString sqlAppend;

    sql = "SELECT rowid, name "
          "FROM teams ";

    if (sSelectedGroup != "All")
    {
        sqlAppend = "WHERE grouprowid=" + QString::number(hGroups.value(sSelectedGroup),10);
        qDebug() << sqlAppend;
        qDebug() << hGroups.value(sSelectedGroup);
    }

    qry.prepare(sql + sqlAppend);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

    ui->cbTeam->clear();
    ui->cbTeam->addItem("All");
    while (qry.isValid())
    {
        ui->cbTeam->addItem(qry.value(1).toString());
        qry.next();
    }
}

void MainWindow::populateRoundCombo()
{
    QSqlQuery qry;
    int iMaxRound;

    qry.prepare("SELECT MAX(round) as maxround "
                 "FROM games ");

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();
    iMaxRound = qry.value(0).toInt();
    ui->cbRounds->clear();
    ui->cbRounds->addItem("All");

    for (int i=1; i<iMaxRound+1; i++)
    {
        ui->cbRounds->addItem(QString::number(i,10));
    }

}

void MainWindow::populateSeasonCombo(QString sSport, QString sRegion, QString sEventName)
{
    QSqlQuery qry;

    qry.prepare("SELECT DISTINCT season "
                 "FROM events "
                 "WHERE sport=:sport and region=:region and name=:name");
    qry.bindValue(":sport", sSport);
    qry.bindValue(":region", sRegion);
    qry.bindValue(":name", sEventName);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();
//    ui->cbSeason->clear();

    while (qry.isValid())
    {
//        ui->cbSeason->addItem(qry.value(0).toString());
        qry.next();
    }

}

void MainWindow::populateEventCombo(QString sSport, QString sRegion)
{
    QSqlQuery qry;


    //    bool bFirst = true;
    qry.prepare("SELECT DISTINCT name "
                 "FROM events "
                 "WHERE sport=:sport and region=:region");
    qry.bindValue(":sport", sSport);
    qry.bindValue(":region", sRegion);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.size();
        qDebug() << qry.lastError();

    }
    qry.next();

//    ui->cbEvents->clear();
    while (qry.isValid())
    {
/*        if (bFirst)
        {
            iEventID = qry.value(0).toInt() ;
            bFirst = false;
        }
*/
//        ui->cbEvents->addItem(qry.value(0).toString());
        qry.next();
    }

}

int MainWindow::populateFavourites()
{
    QSqlQuery qry;
    QString sql;
    int i, j;
    int iRowCount;

    i=0;

    sql ="SELECT showdefault, sport, region, name, url from favourites "
         "ORDER BY sport, region, name ";

    qry.prepare(sql);
    qDebug() << sql;

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    iRowCount = ui->twFavourites->rowCount();
    for (j = 0; j<=iRowCount-1; j++)
    {
        ui->twFavourites->removeRow(0);
    }
    while (qry.next()) {
        ui->twFavourites->setRowCount(ui->twFavourites->rowCount()+1);
        QTableWidgetItem *newItem;

        newItem = new QTableWidgetItem(qry.value(0).toString()); //ShowDefault
        ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 0, newItem);
        newItem = new QTableWidgetItem(qry.value(1).toString()); //Sport
        ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 1, newItem);
        newItem = new QTableWidgetItem(qry.value(2).toString()); //Region
        ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 2, newItem);
        newItem = new QTableWidgetItem(qry.value(3).toString()); //Name
        ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 3, newItem);
        newItem = new QTableWidgetItem(qry.value(4).toString()); //URL
        ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 4, newItem);
        i++;
    }
    return i;
}

void MainWindow::on_twFavourites_clicked ( const QModelIndex & index )
{
    QSqlQuery qry;
    QString sql;
    QTableWidgetItem *qtwiItem;
    int row;

    row = index.row();

    qDebug() << row ;

    qtwiItem = ui->twFavourites->item(row,1);
    qDebug() << qtwiItem ;
    qDebug() << qtwiItem->row();
    qDebug() << qtwiItem->column();
    sSelectedSport = qtwiItem->text();
    qDebug() << sSelectedSport;
    qtwiItem = ui->twFavourites->item(row,2);
    sSelectedRegion = qtwiItem->text();
    qDebug() << sSelectedRegion;
    qtwiItem = ui->twFavourites->item(row,3);
    sSelectedEvent = qtwiItem->text();
    qDebug() << sSelectedEvent;

    sql = "SELECT season, soccerdbid from events "
          "WHERE name=:name and region=:region and sport=:sport "
          "ORDER BY season DESC";
    qry.prepare(sql);
    qry.bindValue(":name", sSelectedEvent);
    qry.bindValue(":region", sSelectedRegion);
    qry.bindValue(":sport", sSelectedSport);


    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    if (qry.next()) {
        sSelectedSeason = qry.value(0).toString();
        iSelectedSoccerDBID = qry.value(1).toInt();
    }

    on_cbSeason_activated(sSelectedSeason);
}

void MainWindow::on_pbAddFavourite_clicked()
{

    QSqlQuery qry;
    QTableWidgetItem *newItem;

// Add SELECT to check if it is already a favourite
    ui->twFavourites->setRowCount(ui->twFavourites->rowCount()+1);

    newItem = new QTableWidgetItem(sSelectedSport);
    ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 1, newItem);

    newItem = new QTableWidgetItem(sSelectedRegion);
    ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 2, newItem);

    newItem = new QTableWidgetItem(sSelectedEvent);
    ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 3, newItem);

    //url
    newItem = new QTableWidgetItem("");
    ui->twFavourites->setItem(ui->twFavourites->rowCount()-1, 4, newItem);

//    return;

    qry.prepare("INSERT INTO favourites (showdefault, sport, region, name, url) VALUES "
                "(:showdefault, :sport, :region, :name, :url)");

    qry.bindValue(":showdefault", 0);
    qry.bindValue(":sport", sSelectedSport);
    qry.bindValue(":region", sSelectedRegion);
    qry.bindValue(":name", sSelectedEvent);
    qry.bindValue(":url", "");

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
        qDebug() << qry.executedQuery();
        qDebug() << qry.boundValues();
    }
    else
    {
        qDebug() << "Event:" << sSelectedEvent;
        iEventID = qry.lastInsertId().toInt();
        qDebug() << "EventID:" << iEventID;
    }

}

void MainWindow::on_pbRemoveFavourite_clicked()
{

    QSqlQuery qry;
    QTableWidgetItem *qtwiItem ;

    QString sql;
    int row;

    row =  ui->twFavourites->selectedItems().first()->row();

    qtwiItem = ui->twFavourites->item(row,1);
    qDebug() << qtwiItem ;
    qDebug() << qtwiItem->row();
    qDebug() << qtwiItem->column();
    sSelectedSport = qtwiItem->text();
    qDebug() << sSelectedSport;
    qtwiItem = ui->twFavourites->item(row,2);
    sSelectedRegion = qtwiItem->text();
    qDebug() << sSelectedRegion;
    qtwiItem = ui->twFavourites->item(row,3);
    sSelectedEvent = qtwiItem->text();
    qDebug() << sSelectedEvent;

    qry.prepare("DELETE FROM favourites "
                "WHERE name=:name and region=:region and sport=:sport ");

    qry.bindValue(":sport", sSelectedSport);
    qry.bindValue(":region", sSelectedRegion);
    qry.bindValue(":name", sSelectedEvent);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
        qDebug() << qry.executedQuery();
        qDebug() << qry.boundValues();
    }
    else
    {
        qDebug() << "Delete Event:" << sSelectedEvent;
        ui->twFavourites->removeRow(row);
    }

}


void MainWindow::on_cbSport_activated(QString sSportName)
{
    sSelectedSport = sSportName;
    populateRegionCombo(sSportName);
//    displayGames();
//    showStandings();
}

void MainWindow::on_cbRegion_activated(QString sRegionName)
{
    sSelectedRegion = sRegionName;
    populateEventCombo(sSelectedSport, sSelectedRegion);
//    displayGames();
//    showStandings();
}

void MainWindow::on_cbEvents_activated(QString sEventName)
{
    sSelectedEvent = sEventName;
    populateSeasonCombo(sSelectedSport, sSelectedRegion, sSelectedEvent);
//    displayGames();
//    showStandings();
}

void MainWindow::on_cbGroups_activated(QString sGroupName)
{
    sSelectedGroup = sGroupName;
    displayGames();
    showStandings();
}

void MainWindow::on_cbSeason_activated(QString sSeason)
{
    QSqlQuery qry;
    QString sql;

    sSelectedSeason = sSeason;
    sql = "SELECT rowid, soccerdbid from events "
          "WHERE name = :name and season = :season and region = :region";
    qry.prepare(sql);
    qry.bindValue(":name", sSelectedEvent);
    qry.bindValue(":season", sSelectedSeason);
    qry.bindValue(":region", sSelectedRegion);

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }

    if (qry.next()) {
        iEventID = qry.value(0).toInt();
        iSelectedSoccerDBID = qry.value(1).toInt();
    }
    else
    {
        iEventID = -1;
    }

    showOnlineLeague(iSelectedSoccerDBID);
    populateGroupCombo();
    populateRoundCombo();
    displayGames();

}

void MainWindow::on_cbRounds_activated(QString sRound)
{
    sSelectedRound = sRound;
    displayGames();
}

void MainWindow::showAbout()
{
    QString message = "";
    QString version;

//    message.append(APP_NAME);
    message.append("QSportsEvent");
    message.append("-");
//    version = version.setNum(APP_VERSION);
    version = "0.0.4";
    message.append(version);
    message.append("\n by ");
//    message.append(AUTHOR);
    message.append("Magnus Lundgren (magnuslu@hotmail.com)");
    message.append("With special thanks to the maemo.org community.");
    QMessageBox::about ( this, tr("About"), message);
}

void MainWindow::showStandings()
{
    QSqlQuery qry;
    QString sql;
    int iHomeTeamID;
    int iAwayTeamID;
    int iHomeGoals;
    int iAwayGoals;
    Standing stHomeTeam;
    Standing stAwayTeam;
    QTableWidgetItem *newItem;

    if (sSelectedGroup == "All" || sSelectedGroup == "")
    {
        qDebug() << "Can't show standings for All groups" << sSelectedGroup;
        return;
    }


    sql ="SELECT hometeamrowid, awayteamrowid, homegoals, awaygoals from games "
         "WHERE grouprowid=" + QString::number(hGroups.value(sSelectedGroup),10);

//    str = hGroups.key(qry.value(column).toInt());
    qry.prepare(sql);
    qDebug() << sql;

    if (!qry.exec())
    {
        qDebug() << qry.lastQuery();
        qDebug() << qry.lastError();
    }
    while (qry.next()) {
        iHomeTeamID = qry.value(0).toInt();
        iAwayTeamID = qry.value(1).toInt();
        iHomeGoals = qry.value(2).toInt();
        iAwayGoals = qry.value(3).toInt();
        stHomeTeam = hStanding.value(iHomeTeamID);
        stAwayTeam = hStanding.value(iAwayTeamID);
        qDebug() << iHomeTeamID << iAwayTeamID << iHomeGoals << iAwayGoals;
        if (iHomeGoals > iAwayGoals)
        {
            stHomeTeam.iPoints=stHomeTeam.iPoints + 3;
            stHomeTeam.iWins++;
            stAwayTeam.iLosses++;
        }
        else if (iHomeGoals < iAwayGoals)
        {
            stAwayTeam.iPoints=stAwayTeam.iPoints + 3;
            stHomeTeam.iLosses++;
            stAwayTeam.iWins++;
        }
        else
        {
            stHomeTeam.iPoints=stHomeTeam.iPoints + 1;
            stAwayTeam.iPoints=stAwayTeam.iPoints + 1;
            stHomeTeam.iDraws++;
            stAwayTeam.iDraws++;
        }

        stHomeTeam.iScored=stHomeTeam.iScored + iHomeGoals;
        stHomeTeam.iConceeded=stHomeTeam.iConceeded + iAwayGoals;
        stAwayTeam.iScored=stAwayTeam.iScored + iAwayGoals;
        stAwayTeam.iConceeded=stAwayTeam.iConceeded + iHomeGoals;

        qDebug() << stHomeTeam.sTeamName << stHomeTeam.iPoints;
        qDebug() << stAwayTeam.sTeamName << stAwayTeam.iPoints;
        hStanding[iHomeTeamID] = stHomeTeam;
        hStanding[iAwayTeamID] = stAwayTeam;
        }

    int j=0;
    QHash<int, Standing>::iterator i;

    ui->twStandings->clear();
    ui->twStandings->setRowCount(hStanding.count());
    ui->twStandings->setColumnCount(9);


    for (i = hStanding.begin(); i != hStanding.end(); ++i)
    {
        stAwayTeam = i.value();

        //Team Name
        newItem = new QTableWidgetItem(stAwayTeam.sTeamName);
        qDebug() << j << stAwayTeam.sTeamName;
        ui->twStandings->setItem(j, 0, newItem);

        //Games played
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iWins +
                                                       stAwayTeam.iDraws +
                                                       stAwayTeam.iLosses,10));
        qDebug() << j << QString::number(stAwayTeam.iPoints,10);
        ui->twStandings->setItem(j, 1, newItem);

        //Games won
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iWins,10));
        qDebug() << j << QString::number(stAwayTeam.iWins,10);
        ui->twStandings->setItem(j, 2, newItem);

        //Games drawn
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iDraws,10));
        qDebug() << j << QString::number(stAwayTeam.iDraws,10);
        ui->twStandings->setItem(j, 3, newItem);

        //Games lost
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iLosses,10));
        qDebug() << j << QString::number(stAwayTeam.iLosses,10);
        ui->twStandings->setItem(j, 4, newItem);

        //Goals for
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iScored,10));
        qDebug() << j << QString::number(stAwayTeam.iScored,10);
        ui->twStandings->setItem(j, 5, newItem);

        //Goals against
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iConceeded,10));
        qDebug() << j << QString::number(stAwayTeam.iConceeded,10);
        ui->twStandings->setItem(j, 6, newItem);

        //Goal difference
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iScored-stAwayTeam.iConceeded,10));
        qDebug() << j << QString::number(stAwayTeam.iScored-stAwayTeam.iConceeded,10);
        ui->twStandings->setItem(j, 7, newItem);

        //Points
        newItem = new QTableWidgetItem(QString::number(stAwayTeam.iPoints,10));
        qDebug() << j << QString::number(stAwayTeam.iPoints,10);
        ui->twStandings->setItem(j, 8, newItem);

        j++;
    }
    ui->twStandings->resizeColumnsToContents();
}
